==> mate-terminal_1.2.1.orig.tar.xz: mate-terminal-1.2.1/src/extra-strings.c <==
/*
 * Copyright © 2009 Christian Persch
 *
 * Mate-terminal is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Mate-terminal is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/* This file contains extra strings that need to be translated, but
 * can't be extracted by intltool since the ui files aren't in git, and
 * the glade files don't contain them in the right form. See bug #553357.
 */

/* Translators: This refers to the Delete keybinding option */
N_("Automatic")
/* Translators: This refers to the Delete keybinding option */
N_("Control-H")
/* Translators: This refers to the Delete keybinding option */
N_("ASCII DEL")
/* Translators: This refers to the Delete keybinding option */
N_("Escape sequence")
/* Translators: This refers to the Delete keybinding option */
N_("TTY Erase")

/* Translators: Cursor shape: ... */
N_("Block")
/* Translators: Cursor shape: ... */
N_("I-Beam")
/* Translators: Cursor shape: ... */
N_("Underline")

/* Translators: When command exits: ... */
N_("Exit the terminal")
/* Translators: When command exits: ... */
N_("Restart the command")
/* Translators: When command exits: ... */
N_("Hold the terminal open")

/* Translators: Scrollbar is: ... */
N_("On the left side")
/* Translators: Scrollbar is: ... */
N_("On the right side")
/* Translators: Scrollbar is: ... */
N_("Disabled")

/* Translators: When terminal commands set their own titles: ... */
N_("Replace initial title")
/* Translators: When terminal commands set their own titles: ... */
N_("Append initial title")
/* Translators: When terminal commands set their own titles: ... */
N_("Prepend initial title")
/* Translators: When terminal commands set their own titles: ... */
N_("Keep initial title")

/* Translators: This is the name of a colour scheme */
N_("Tango")
/* Translators: This is the name of a colour scheme */
N_("Linux console")
/* Translators: This is the name of a colour scheme */
N_("XTerm")
/* Translators: This is the name of a colour scheme */
N_("Rxvt")
/* Translators: This is the name of a colour scheme */
N_("Custom")

==> mate-terminal_1.18.2.orig.tar.xz: mate-terminal-1.18.2/src/extra-strings.c <==
/*
 * Copyright © 2009 Christian Persch
 *
 * Mate-terminal is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Mate-terminal is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/* This file contains extra strings that need to be translated, but
 * can't be extracted by intltool since the ui files aren't in git, and
 * the glade files don't contain them in the right form. See bug #553357.
 */

/* Translators: This refers to the Delete keybinding option */
N_("Automatic")
/* Translators: This refers to the Delete keybinding option */
N_("Control-H")
/* Translators: This refers to the Delete keybinding option */
N_("ASCII DEL")
/* Translators: This refers to the Delete keybinding option */
N_("Escape sequence")
/* Translators: This refers to the Delete keybinding option */
N_("TTY Erase")

/* Translators: Cursor shape: ... */
N_("Block")
/* Translators: Cursor shape: ... */
N_("I-Beam")
/* Translators: Cursor shape: ... */
N_("Underline")

/* Translators: Cursor blink: ... */
N_("Use system settings")
/* Translators: Cursor blink: ... */
N_("Always blink")
/* Translators: Cursor blink: ... */
N_("Never blink")

/* Translators: When command exits: ... */
N_("Exit the terminal")
/* Translators: When command exits: ... */
N_("Restart the command")
/* Translators: When command exits: ... */
N_("Hold the terminal open")

/* Translators: Scrollbar is: ... */
N_("On the left side")
/* Translators: Scrollbar is: ... */
N_("On the right side")
/* Translators: Scrollbar is: ... */
N_("Disabled")

/* Translators: When terminal commands set their own titles: ... */
N_("Replace initial title")
/* Translators: When terminal commands set their own titles: ... */
N_("Append initial title")
/* Translators: When terminal commands set their own titles: ... */
N_("Prepend initial title")
/* Translators: When terminal commands set their own titles: ... */
N_("Keep initial title")

/* Translators: This is the name of a colour scheme */
N_("Tango")
/* Translators: This is the name of a colour scheme */
N_("Linux console")
/* Translators: This is the name of a colour scheme */
N_("XTerm")
/* Translators: This is the name of a colour scheme */
N_("Rxvt")
/* Translators: This is the name of a colour scheme */
N_("Custom")
